# Generated from Py0.g4 by ANTLR 4.13.2
from antlr4 import *
if "." in __name__:
    from .Py0Parser import Py0Parser
else:
    from Py0Parser import Py0Parser

# This class defines a complete listener for a parse tree produced by Py0Parser.
class Py0Listener(ParseTreeListener):

    # Enter a parse tree produced by Py0Parser#program.
    def enterProgram(self, ctx:Py0Parser.ProgramContext):
        pass

    # Exit a parse tree produced by Py0Parser#program.
    def exitProgram(self, ctx:Py0Parser.ProgramContext):
        pass


    # Enter a parse tree produced by Py0Parser#statement.
    def enterStatement(self, ctx:Py0Parser.StatementContext):
        pass

    # Exit a parse tree produced by Py0Parser#statement.
    def exitStatement(self, ctx:Py0Parser.StatementContext):
        pass


    # Enter a parse tree produced by Py0Parser#functionDecl.
    def enterFunctionDecl(self, ctx:Py0Parser.FunctionDeclContext):
        pass

    # Exit a parse tree produced by Py0Parser#functionDecl.
    def exitFunctionDecl(self, ctx:Py0Parser.FunctionDeclContext):
        pass


    # Enter a parse tree produced by Py0Parser#ifStatement.
    def enterIfStatement(self, ctx:Py0Parser.IfStatementContext):
        pass

    # Exit a parse tree produced by Py0Parser#ifStatement.
    def exitIfStatement(self, ctx:Py0Parser.IfStatementContext):
        pass


    # Enter a parse tree produced by Py0Parser#elseIfStatement.
    def enterElseIfStatement(self, ctx:Py0Parser.ElseIfStatementContext):
        pass

    # Exit a parse tree produced by Py0Parser#elseIfStatement.
    def exitElseIfStatement(self, ctx:Py0Parser.ElseIfStatementContext):
        pass


    # Enter a parse tree produced by Py0Parser#elseStatement.
    def enterElseStatement(self, ctx:Py0Parser.ElseStatementContext):
        pass

    # Exit a parse tree produced by Py0Parser#elseStatement.
    def exitElseStatement(self, ctx:Py0Parser.ElseStatementContext):
        pass


    # Enter a parse tree produced by Py0Parser#forStatement.
    def enterForStatement(self, ctx:Py0Parser.ForStatementContext):
        pass

    # Exit a parse tree produced by Py0Parser#forStatement.
    def exitForStatement(self, ctx:Py0Parser.ForStatementContext):
        pass


    # Enter a parse tree produced by Py0Parser#whileStatement.
    def enterWhileStatement(self, ctx:Py0Parser.WhileStatementContext):
        pass

    # Exit a parse tree produced by Py0Parser#whileStatement.
    def exitWhileStatement(self, ctx:Py0Parser.WhileStatementContext):
        pass


    # Enter a parse tree produced by Py0Parser#repeatStatement.
    def enterRepeatStatement(self, ctx:Py0Parser.RepeatStatementContext):
        pass

    # Exit a parse tree produced by Py0Parser#repeatStatement.
    def exitRepeatStatement(self, ctx:Py0Parser.RepeatStatementContext):
        pass


    # Enter a parse tree produced by Py0Parser#block.
    def enterBlock(self, ctx:Py0Parser.BlockContext):
        pass

    # Exit a parse tree produced by Py0Parser#block.
    def exitBlock(self, ctx:Py0Parser.BlockContext):
        pass


    # Enter a parse tree produced by Py0Parser#simpleStatement.
    def enterSimpleStatement(self, ctx:Py0Parser.SimpleStatementContext):
        pass

    # Exit a parse tree produced by Py0Parser#simpleStatement.
    def exitSimpleStatement(self, ctx:Py0Parser.SimpleStatementContext):
        pass


    # Enter a parse tree produced by Py0Parser#expr.
    def enterExpr(self, ctx:Py0Parser.ExprContext):
        pass

    # Exit a parse tree produced by Py0Parser#expr.
    def exitExpr(self, ctx:Py0Parser.ExprContext):
        pass


    # Enter a parse tree produced by Py0Parser#baseExpr.
    def enterBaseExpr(self, ctx:Py0Parser.BaseExprContext):
        pass

    # Exit a parse tree produced by Py0Parser#baseExpr.
    def exitBaseExpr(self, ctx:Py0Parser.BaseExprContext):
        pass



del Py0Parser


# Generated from Py0.g4 by ANTLR 4.13.2
from antlr4 import *
if "." in __name__:
    from .Py0Parser import Py0Parser
else:
    from Py0Parser import Py0Parser

# This class defines a complete generic visitor for a parse tree produced by Py0Parser.

class Py0Visitor(ParseTreeVisitor):

    # Visit a parse tree produced by Py0Parser#program.
    def visitProgram(self, ctx:Py0Parser.ProgramContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#statement.
    def visitStatement(self, ctx:Py0Parser.StatementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#functionDecl.
    def visitFunctionDecl(self, ctx:Py0Parser.FunctionDeclContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#ifStatement.
    def visitIfStatement(self, ctx:Py0Parser.IfStatementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#elseIfStatement.
    def visitElseIfStatement(self, ctx:Py0Parser.ElseIfStatementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#elseStatement.
    def visitElseStatement(self, ctx:Py0Parser.ElseStatementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#forStatement.
    def visitForStatement(self, ctx:Py0Parser.ForStatementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#whileStatement.
    def visitWhileStatement(self, ctx:Py0Parser.WhileStatementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#repeatStatement.
    def visitRepeatStatement(self, ctx:Py0Parser.RepeatStatementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#block.
    def visitBlock(self, ctx:Py0Parser.BlockContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#simpleStatement.
    def visitSimpleStatement(self, ctx:Py0Parser.SimpleStatementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#expr.
    def visitExpr(self, ctx:Py0Parser.ExprContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by Py0Parser#baseExpr.
    def visitBaseExpr(self, ctx:Py0Parser.BaseExprContext):
        return self.visitChildren(ctx)



del Py0Parser


import os
import sys
import subprocess
from .transpiler import transpile_file

def main():
    if len(sys.argv) != 2:
        print("Usage: py0 <filename.py0>")
        sys.exit(1)

    input_file = sys.argv[1]
    if not input_file.endswith('.py0'):
        print("Error: Input file must have .py0 extension")
        sys.exit(1)

    dir_path = os.path.dirname(os.path.abspath(input_file))
    for file in os.listdir(dir_path):
        if file.endswith('.py0'):
            py0_file = os.path.join(dir_path, file)
            py_file = py0_file[:-4] + '.py'
            transpile_file(py0_file, py_file)
            print(f"Transpiled {py0_file} to {py_file}")

    output_file = input_file[:-4] + '.py'
    subprocess.run(['python', output_file])

if __name__ == '__main__':
    main()


# Generated from Py0.g4 by ANTLR 4.13.2
# encoding: utf-8
from antlr4 import *
from io import StringIO
import sys
if sys.version_info[1] > 5:
	from typing import TextIO
else:
	from typing.io import TextIO

def serializedATN():
    return [
        4,1,17,119,2,0,7,0,2,1,7,1,2,2,7,2,2,3,7,3,2,4,7,4,2,5,7,5,2,6,7,
        6,2,7,7,7,2,8,7,8,2,9,7,9,2,10,7,10,2,11,7,11,2,12,7,12,1,0,1,0,
        1,0,5,0,30,8,0,10,0,12,0,33,9,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,
        3,1,43,8,1,1,2,1,2,1,2,1,2,1,2,1,2,1,3,1,3,1,3,1,3,1,3,5,3,56,8,
        3,10,3,12,3,59,9,3,1,3,3,3,62,8,3,1,3,1,3,1,4,1,4,1,4,1,4,1,4,1,
        4,1,5,1,5,1,5,1,5,1,6,1,6,1,6,1,6,1,6,1,6,1,7,1,7,1,7,1,7,1,7,1,
        7,1,8,1,8,1,8,1,8,1,8,1,8,1,9,1,9,1,9,1,9,5,9,98,8,9,10,9,12,9,101,
        9,9,1,10,1,10,1,10,1,11,1,11,1,11,1,11,1,11,1,11,3,11,112,8,11,1,
        12,4,12,115,8,12,11,12,12,12,116,1,12,0,0,13,0,2,4,6,8,10,12,14,
        16,18,20,22,24,0,2,1,1,16,16,1,0,9,14,121,0,31,1,0,0,0,2,42,1,0,
        0,0,4,44,1,0,0,0,6,50,1,0,0,0,8,65,1,0,0,0,10,71,1,0,0,0,12,75,1,
        0,0,0,14,81,1,0,0,0,16,87,1,0,0,0,18,99,1,0,0,0,20,102,1,0,0,0,22,
        105,1,0,0,0,24,114,1,0,0,0,26,30,3,2,1,0,27,30,5,16,0,0,28,30,5,
        15,0,0,29,26,1,0,0,0,29,27,1,0,0,0,29,28,1,0,0,0,30,33,1,0,0,0,31,
        29,1,0,0,0,31,32,1,0,0,0,32,34,1,0,0,0,33,31,1,0,0,0,34,35,5,0,0,
        1,35,1,1,0,0,0,36,43,3,4,2,0,37,43,3,6,3,0,38,43,3,12,6,0,39,43,
        3,14,7,0,40,43,3,16,8,0,41,43,3,20,10,0,42,36,1,0,0,0,42,37,1,0,
        0,0,42,38,1,0,0,0,42,39,1,0,0,0,42,40,1,0,0,0,42,41,1,0,0,0,43,3,
        1,0,0,0,44,45,5,2,0,0,45,46,3,22,11,0,46,47,5,16,0,0,47,48,3,18,
        9,0,48,49,5,1,0,0,49,5,1,0,0,0,50,51,5,3,0,0,51,52,3,22,11,0,52,
        53,5,16,0,0,53,57,3,18,9,0,54,56,3,8,4,0,55,54,1,0,0,0,56,59,1,0,
        0,0,57,55,1,0,0,0,57,58,1,0,0,0,58,61,1,0,0,0,59,57,1,0,0,0,60,62,
        3,10,5,0,61,60,1,0,0,0,61,62,1,0,0,0,62,63,1,0,0,0,63,64,5,1,0,0,
        64,7,1,0,0,0,65,66,5,4,0,0,66,67,5,3,0,0,67,68,3,22,11,0,68,69,5,
        16,0,0,69,70,3,18,9,0,70,9,1,0,0,0,71,72,5,4,0,0,72,73,5,16,0,0,
        73,74,3,18,9,0,74,11,1,0,0,0,75,76,5,5,0,0,76,77,3,22,11,0,77,78,
        5,16,0,0,78,79,3,18,9,0,79,80,5,1,0,0,80,13,1,0,0,0,81,82,5,6,0,
        0,82,83,3,22,11,0,83,84,5,16,0,0,84,85,3,18,9,0,85,86,5,1,0,0,86,
        15,1,0,0,0,87,88,5,7,0,0,88,89,3,22,11,0,89,90,5,16,0,0,90,91,3,
        18,9,0,91,92,5,1,0,0,92,17,1,0,0,0,93,98,3,2,1,0,94,98,3,20,10,0,
        95,98,5,16,0,0,96,98,5,15,0,0,97,93,1,0,0,0,97,94,1,0,0,0,97,95,
        1,0,0,0,97,96,1,0,0,0,98,101,1,0,0,0,99,97,1,0,0,0,99,100,1,0,0,
        0,100,19,1,0,0,0,101,99,1,0,0,0,102,103,3,22,11,0,103,104,7,0,0,
        0,104,21,1,0,0,0,105,111,3,24,12,0,106,107,5,3,0,0,107,108,3,24,
        12,0,108,109,5,4,0,0,109,110,3,24,12,0,110,112,1,0,0,0,111,106,1,
        0,0,0,111,112,1,0,0,0,112,23,1,0,0,0,113,115,7,1,0,0,114,113,1,0,
        0,0,115,116,1,0,0,0,116,114,1,0,0,0,116,117,1,0,0,0,117,25,1,0,0,
        0,9,29,31,42,57,61,97,99,111,116
    ]

class Py0Parser ( Parser ):

    grammarFileName = "Py0.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "<INVALID>", "'function'", "'if'", "'else'", 
                     "'for'", "'while'", "'repeat'", "'end'", "'=>'" ]

    symbolicNames = [ "<INVALID>", "END_LINE", "FUNCTION", "IF", "ELSE", 
                      "FOR", "WHILE", "REPEAT", "END", "ARROW", "IDENTIFIER", 
                      "NUMBER", "STRING", "OPERATOR", "SYMBOL", "COMMENT", 
                      "NL", "WS" ]

    RULE_program = 0
    RULE_statement = 1
    RULE_functionDecl = 2
    RULE_ifStatement = 3
    RULE_elseIfStatement = 4
    RULE_elseStatement = 5
    RULE_forStatement = 6
    RULE_whileStatement = 7
    RULE_repeatStatement = 8
    RULE_block = 9
    RULE_simpleStatement = 10
    RULE_expr = 11
    RULE_baseExpr = 12

    ruleNames =  [ "program", "statement", "functionDecl", "ifStatement", 
                   "elseIfStatement", "elseStatement", "forStatement", "whileStatement", 
                   "repeatStatement", "block", "simpleStatement", "expr", 
                   "baseExpr" ]

    EOF = Token.EOF
    END_LINE=1
    FUNCTION=2
    IF=3
    ELSE=4
    FOR=5
    WHILE=6
    REPEAT=7
    END=8
    ARROW=9
    IDENTIFIER=10
    NUMBER=11
    STRING=12
    OPERATOR=13
    SYMBOL=14
    COMMENT=15
    NL=16
    WS=17

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.13.2")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None




    class ProgramContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EOF(self):
            return self.getToken(Py0Parser.EOF, 0)

        def statement(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(Py0Parser.StatementContext)
            else:
                return self.getTypedRuleContext(Py0Parser.StatementContext,i)


        def NL(self, i:int=None):
            if i is None:
                return self.getTokens(Py0Parser.NL)
            else:
                return self.getToken(Py0Parser.NL, i)

        def COMMENT(self, i:int=None):
            if i is None:
                return self.getTokens(Py0Parser.COMMENT)
            else:
                return self.getToken(Py0Parser.COMMENT, i)

        def getRuleIndex(self):
            return Py0Parser.RULE_program

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProgram" ):
                listener.enterProgram(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProgram" ):
                listener.exitProgram(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitProgram" ):
                return visitor.visitProgram(self)
            else:
                return visitor.visitChildren(self)




    def program(self):

        localctx = Py0Parser.ProgramContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_program)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 31
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 130796) != 0):
                self.state = 29
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [2, 3, 5, 6, 7, 9, 10, 11, 12, 13, 14]:
                    self.state = 26
                    self.statement()
                    pass
                elif token in [16]:
                    self.state = 27
                    self.match(Py0Parser.NL)
                    pass
                elif token in [15]:
                    self.state = 28
                    self.match(Py0Parser.COMMENT)
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 33
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 34
            self.match(Py0Parser.EOF)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class StatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def functionDecl(self):
            return self.getTypedRuleContext(Py0Parser.FunctionDeclContext,0)


        def ifStatement(self):
            return self.getTypedRuleContext(Py0Parser.IfStatementContext,0)


        def forStatement(self):
            return self.getTypedRuleContext(Py0Parser.ForStatementContext,0)


        def whileStatement(self):
            return self.getTypedRuleContext(Py0Parser.WhileStatementContext,0)


        def repeatStatement(self):
            return self.getTypedRuleContext(Py0Parser.RepeatStatementContext,0)


        def simpleStatement(self):
            return self.getTypedRuleContext(Py0Parser.SimpleStatementContext,0)


        def getRuleIndex(self):
            return Py0Parser.RULE_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStatement" ):
                listener.enterStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStatement" ):
                listener.exitStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitStatement" ):
                return visitor.visitStatement(self)
            else:
                return visitor.visitChildren(self)




    def statement(self):

        localctx = Py0Parser.StatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_statement)
        try:
            self.state = 42
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [2]:
                self.enterOuterAlt(localctx, 1)
                self.state = 36
                self.functionDecl()
                pass
            elif token in [3]:
                self.enterOuterAlt(localctx, 2)
                self.state = 37
                self.ifStatement()
                pass
            elif token in [5]:
                self.enterOuterAlt(localctx, 3)
                self.state = 38
                self.forStatement()
                pass
            elif token in [6]:
                self.enterOuterAlt(localctx, 4)
                self.state = 39
                self.whileStatement()
                pass
            elif token in [7]:
                self.enterOuterAlt(localctx, 5)
                self.state = 40
                self.repeatStatement()
                pass
            elif token in [9, 10, 11, 12, 13, 14]:
                self.enterOuterAlt(localctx, 6)
                self.state = 41
                self.simpleStatement()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FunctionDeclContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FUNCTION(self):
            return self.getToken(Py0Parser.FUNCTION, 0)

        def expr(self):
            return self.getTypedRuleContext(Py0Parser.ExprContext,0)


        def NL(self):
            return self.getToken(Py0Parser.NL, 0)

        def block(self):
            return self.getTypedRuleContext(Py0Parser.BlockContext,0)


        def END_LINE(self):
            return self.getToken(Py0Parser.END_LINE, 0)

        def getRuleIndex(self):
            return Py0Parser.RULE_functionDecl

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFunctionDecl" ):
                listener.enterFunctionDecl(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFunctionDecl" ):
                listener.exitFunctionDecl(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFunctionDecl" ):
                return visitor.visitFunctionDecl(self)
            else:
                return visitor.visitChildren(self)




    def functionDecl(self):

        localctx = Py0Parser.FunctionDeclContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_functionDecl)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 44
            self.match(Py0Parser.FUNCTION)
            self.state = 45
            self.expr()
            self.state = 46
            self.match(Py0Parser.NL)
            self.state = 47
            self.block()
            self.state = 48
            self.match(Py0Parser.END_LINE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class IfStatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def IF(self):
            return self.getToken(Py0Parser.IF, 0)

        def expr(self):
            return self.getTypedRuleContext(Py0Parser.ExprContext,0)


        def NL(self):
            return self.getToken(Py0Parser.NL, 0)

        def block(self):
            return self.getTypedRuleContext(Py0Parser.BlockContext,0)


        def END_LINE(self):
            return self.getToken(Py0Parser.END_LINE, 0)

        def elseIfStatement(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(Py0Parser.ElseIfStatementContext)
            else:
                return self.getTypedRuleContext(Py0Parser.ElseIfStatementContext,i)


        def elseStatement(self):
            return self.getTypedRuleContext(Py0Parser.ElseStatementContext,0)


        def getRuleIndex(self):
            return Py0Parser.RULE_ifStatement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIfStatement" ):
                listener.enterIfStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIfStatement" ):
                listener.exitIfStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitIfStatement" ):
                return visitor.visitIfStatement(self)
            else:
                return visitor.visitChildren(self)




    def ifStatement(self):

        localctx = Py0Parser.IfStatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_ifStatement)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 50
            self.match(Py0Parser.IF)
            self.state = 51
            self.expr()
            self.state = 52
            self.match(Py0Parser.NL)
            self.state = 53
            self.block()
            self.state = 57
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,3,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 54
                    self.elseIfStatement() 
                self.state = 59
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,3,self._ctx)

            self.state = 61
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 60
                self.elseStatement()


            self.state = 63
            self.match(Py0Parser.END_LINE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ElseIfStatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ELSE(self):
            return self.getToken(Py0Parser.ELSE, 0)

        def IF(self):
            return self.getToken(Py0Parser.IF, 0)

        def expr(self):
            return self.getTypedRuleContext(Py0Parser.ExprContext,0)


        def NL(self):
            return self.getToken(Py0Parser.NL, 0)

        def block(self):
            return self.getTypedRuleContext(Py0Parser.BlockContext,0)


        def getRuleIndex(self):
            return Py0Parser.RULE_elseIfStatement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterElseIfStatement" ):
                listener.enterElseIfStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitElseIfStatement" ):
                listener.exitElseIfStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitElseIfStatement" ):
                return visitor.visitElseIfStatement(self)
            else:
                return visitor.visitChildren(self)




    def elseIfStatement(self):

        localctx = Py0Parser.ElseIfStatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_elseIfStatement)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 65
            self.match(Py0Parser.ELSE)
            self.state = 66
            self.match(Py0Parser.IF)
            self.state = 67
            self.expr()
            self.state = 68
            self.match(Py0Parser.NL)
            self.state = 69
            self.block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ElseStatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ELSE(self):
            return self.getToken(Py0Parser.ELSE, 0)

        def NL(self):
            return self.getToken(Py0Parser.NL, 0)

        def block(self):
            return self.getTypedRuleContext(Py0Parser.BlockContext,0)


        def getRuleIndex(self):
            return Py0Parser.RULE_elseStatement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterElseStatement" ):
                listener.enterElseStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitElseStatement" ):
                listener.exitElseStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitElseStatement" ):
                return visitor.visitElseStatement(self)
            else:
                return visitor.visitChildren(self)




    def elseStatement(self):

        localctx = Py0Parser.ElseStatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_elseStatement)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 71
            self.match(Py0Parser.ELSE)
            self.state = 72
            self.match(Py0Parser.NL)
            self.state = 73
            self.block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ForStatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FOR(self):
            return self.getToken(Py0Parser.FOR, 0)

        def expr(self):
            return self.getTypedRuleContext(Py0Parser.ExprContext,0)


        def NL(self):
            return self.getToken(Py0Parser.NL, 0)

        def block(self):
            return self.getTypedRuleContext(Py0Parser.BlockContext,0)


        def END_LINE(self):
            return self.getToken(Py0Parser.END_LINE, 0)

        def getRuleIndex(self):
            return Py0Parser.RULE_forStatement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterForStatement" ):
                listener.enterForStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitForStatement" ):
                listener.exitForStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitForStatement" ):
                return visitor.visitForStatement(self)
            else:
                return visitor.visitChildren(self)




    def forStatement(self):

        localctx = Py0Parser.ForStatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_forStatement)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 75
            self.match(Py0Parser.FOR)
            self.state = 76
            self.expr()
            self.state = 77
            self.match(Py0Parser.NL)
            self.state = 78
            self.block()
            self.state = 79
            self.match(Py0Parser.END_LINE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class WhileStatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def WHILE(self):
            return self.getToken(Py0Parser.WHILE, 0)

        def expr(self):
            return self.getTypedRuleContext(Py0Parser.ExprContext,0)


        def NL(self):
            return self.getToken(Py0Parser.NL, 0)

        def block(self):
            return self.getTypedRuleContext(Py0Parser.BlockContext,0)


        def END_LINE(self):
            return self.getToken(Py0Parser.END_LINE, 0)

        def getRuleIndex(self):
            return Py0Parser.RULE_whileStatement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWhileStatement" ):
                listener.enterWhileStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWhileStatement" ):
                listener.exitWhileStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWhileStatement" ):
                return visitor.visitWhileStatement(self)
            else:
                return visitor.visitChildren(self)




    def whileStatement(self):

        localctx = Py0Parser.WhileStatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_whileStatement)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 81
            self.match(Py0Parser.WHILE)
            self.state = 82
            self.expr()
            self.state = 83
            self.match(Py0Parser.NL)
            self.state = 84
            self.block()
            self.state = 85
            self.match(Py0Parser.END_LINE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class RepeatStatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REPEAT(self):
            return self.getToken(Py0Parser.REPEAT, 0)

        def expr(self):
            return self.getTypedRuleContext(Py0Parser.ExprContext,0)


        def NL(self):
            return self.getToken(Py0Parser.NL, 0)

        def block(self):
            return self.getTypedRuleContext(Py0Parser.BlockContext,0)


        def END_LINE(self):
            return self.getToken(Py0Parser.END_LINE, 0)

        def getRuleIndex(self):
            return Py0Parser.RULE_repeatStatement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRepeatStatement" ):
                listener.enterRepeatStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRepeatStatement" ):
                listener.exitRepeatStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRepeatStatement" ):
                return visitor.visitRepeatStatement(self)
            else:
                return visitor.visitChildren(self)




    def repeatStatement(self):

        localctx = Py0Parser.RepeatStatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 16, self.RULE_repeatStatement)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 87
            self.match(Py0Parser.REPEAT)
            self.state = 88
            self.expr()
            self.state = 89
            self.match(Py0Parser.NL)
            self.state = 90
            self.block()
            self.state = 91
            self.match(Py0Parser.END_LINE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class BlockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def statement(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(Py0Parser.StatementContext)
            else:
                return self.getTypedRuleContext(Py0Parser.StatementContext,i)


        def simpleStatement(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(Py0Parser.SimpleStatementContext)
            else:
                return self.getTypedRuleContext(Py0Parser.SimpleStatementContext,i)


        def NL(self, i:int=None):
            if i is None:
                return self.getTokens(Py0Parser.NL)
            else:
                return self.getToken(Py0Parser.NL, i)

        def COMMENT(self, i:int=None):
            if i is None:
                return self.getTokens(Py0Parser.COMMENT)
            else:
                return self.getToken(Py0Parser.COMMENT, i)

        def getRuleIndex(self):
            return Py0Parser.RULE_block

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBlock" ):
                listener.enterBlock(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBlock" ):
                listener.exitBlock(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBlock" ):
                return visitor.visitBlock(self)
            else:
                return visitor.visitChildren(self)




    def block(self):

        localctx = Py0Parser.BlockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 18, self.RULE_block)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 99
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 130796) != 0):
                self.state = 97
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,5,self._ctx)
                if la_ == 1:
                    self.state = 93
                    self.statement()
                    pass

                elif la_ == 2:
                    self.state = 94
                    self.simpleStatement()
                    pass

                elif la_ == 3:
                    self.state = 95
                    self.match(Py0Parser.NL)
                    pass

                elif la_ == 4:
                    self.state = 96
                    self.match(Py0Parser.COMMENT)
                    pass


                self.state = 101
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SimpleStatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expr(self):
            return self.getTypedRuleContext(Py0Parser.ExprContext,0)


        def NL(self):
            return self.getToken(Py0Parser.NL, 0)

        def EOF(self):
            return self.getToken(Py0Parser.EOF, 0)

        def getRuleIndex(self):
            return Py0Parser.RULE_simpleStatement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSimpleStatement" ):
                listener.enterSimpleStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSimpleStatement" ):
                listener.exitSimpleStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSimpleStatement" ):
                return visitor.visitSimpleStatement(self)
            else:
                return visitor.visitChildren(self)




    def simpleStatement(self):

        localctx = Py0Parser.SimpleStatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 20, self.RULE_simpleStatement)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 102
            self.expr()
            self.state = 103
            _la = self._input.LA(1)
            if not(_la==-1 or _la==16):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ExprContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def baseExpr(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(Py0Parser.BaseExprContext)
            else:
                return self.getTypedRuleContext(Py0Parser.BaseExprContext,i)


        def IF(self):
            return self.getToken(Py0Parser.IF, 0)

        def ELSE(self):
            return self.getToken(Py0Parser.ELSE, 0)

        def getRuleIndex(self):
            return Py0Parser.RULE_expr

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExpr" ):
                listener.enterExpr(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExpr" ):
                listener.exitExpr(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExpr" ):
                return visitor.visitExpr(self)
            else:
                return visitor.visitChildren(self)




    def expr(self):

        localctx = Py0Parser.ExprContext(self, self._ctx, self.state)
        self.enterRule(localctx, 22, self.RULE_expr)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 105
            self.baseExpr()
            self.state = 111
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==3:
                self.state = 106
                self.match(Py0Parser.IF)
                self.state = 107
                self.baseExpr()
                self.state = 108
                self.match(Py0Parser.ELSE)
                self.state = 109
                self.baseExpr()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class BaseExprContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def IDENTIFIER(self, i:int=None):
            if i is None:
                return self.getTokens(Py0Parser.IDENTIFIER)
            else:
                return self.getToken(Py0Parser.IDENTIFIER, i)

        def NUMBER(self, i:int=None):
            if i is None:
                return self.getTokens(Py0Parser.NUMBER)
            else:
                return self.getToken(Py0Parser.NUMBER, i)

        def STRING(self, i:int=None):
            if i is None:
                return self.getTokens(Py0Parser.STRING)
            else:
                return self.getToken(Py0Parser.STRING, i)

        def OPERATOR(self, i:int=None):
            if i is None:
                return self.getTokens(Py0Parser.OPERATOR)
            else:
                return self.getToken(Py0Parser.OPERATOR, i)

        def SYMBOL(self, i:int=None):
            if i is None:
                return self.getTokens(Py0Parser.SYMBOL)
            else:
                return self.getToken(Py0Parser.SYMBOL, i)

        def ARROW(self, i:int=None):
            if i is None:
                return self.getTokens(Py0Parser.ARROW)
            else:
                return self.getToken(Py0Parser.ARROW, i)

        def getRuleIndex(self):
            return Py0Parser.RULE_baseExpr

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBaseExpr" ):
                listener.enterBaseExpr(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBaseExpr" ):
                listener.exitBaseExpr(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBaseExpr" ):
                return visitor.visitBaseExpr(self)
            else:
                return visitor.visitChildren(self)




    def baseExpr(self):

        localctx = Py0Parser.BaseExprContext(self, self._ctx, self.state)
        self.enterRule(localctx, 24, self.RULE_baseExpr)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 114 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 113
                _la = self._input.LA(1)
                if not((((_la) & ~0x3f) == 0 and ((1 << _la) & 32256) != 0)):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 116 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not ((((_la) & ~0x3f) == 0 and ((1 << _la) & 32256) != 0)):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx








import re
from antlr4 import *
from py0.generated.Py0Lexer import Py0Lexer
from py0.generated.Py0Parser import Py0Parser
from py0.generated.Py0Listener import Py0Listener

class Py0ToPythonTranspiler(Py0Listener):
    def __init__(self, input_stream):
        self.output = []
        self.indent = 0
        self.input_stream = input_stream
        self.current_line = -1

    def get_indent(self):
        return '    ' * self.indent

    def enterFunctionDecl(self, ctx: Py0Parser.FunctionDeclContext):
        func_header = self.get_expr_text(ctx)
        self.output.append(f"{self.get_indent()}def {func_header}:\n")
        self.indent += 1

    def exitFunctionDecl(self, ctx: Py0Parser.FunctionDeclContext):
        self.indent -= 1

    def enterForStatement(self, ctx: Py0Parser.ForStatementContext):
        expr = self.get_expr_text(ctx)
        self.output.append(f"{self.get_indent()}for {expr}:\n")
        self.indent += 1

    def exitForStatement(self, ctx: Py0Parser.ForStatementContext):
        self.indent -= 1

    def enterWhileStatement(self, ctx: Py0Parser.WhileStatementContext):
        expr = self.get_expr_text(ctx)
        self.output.append(f"{self.get_indent()}while {expr}:\n")
        self.indent += 1

    def exitWhileStatement(self, ctx: Py0Parser.WhileStatementContext):
        self.indent -= 1

    def enterRepeatStatement(self, ctx: Py0Parser.RepeatStatementContext):
        expr = self.get_expr_text(ctx)
        self.output.append(f"{self.get_indent()}for _ in range({expr}):\n")
        self.indent += 1

    def exitRepeatStatement(self, ctx: Py0Parser.RepeatStatementContext):
        self.indent -= 1

    def enterIfStatement(self, ctx: Py0Parser.IfStatementContext):
        expr = self.get_expr_text(ctx)
        self.output.append(f"{self.get_indent()}if {expr}:\n")
        self.indent += 1

    def exitIfStatement(self, ctx: Py0Parser.IfStatementContext):
        self.indent -= 1

    def enterElseIfStatement(self, ctx: Py0Parser.ElseIfStatementContext):
        expr = self.get_expr_text(ctx)
        self.indent -= 1
        self.output.append(f"{self.get_indent()}elif {expr}:\n")
        self.indent += 1

    def enterElseStatement(self, ctx: Py0Parser.ElseStatementContext):
        self.indent -= 1
        self.output.append(f"{self.get_indent()}else:\n")
        self.indent += 1

    def enterSimpleStatement(self, ctx: Py0Parser.SimpleStatementContext):
        start_index = ctx.start.start
        stop_index = ctx.stop.stop
        stmt = self.input_stream.getText(start_index, stop_index).strip()
        line_number = ctx.start.line
        if line_number != self.current_line:
            stmt = self.convert_arrow_function(stmt)
            self.output.append(f"{self.get_indent()}{stmt}\n")
            self.current_line = line_number

    def convert_arrow_function(self, stmt):
        # Patterns for different types of arrow functions
        pattern1 = r'^(\w+)\s*=\s*\(\s*(.*?)\s*\)\s*=>\s*(.*)$'
        pattern2 = r'^(\w+)\s*=\s*(\w+)\s*=>\s*(.*)$'
        pattern3 = r'^(\w+)\s*=\s*\(\s*\)\s*=>\s*(.*)$'
        pattern4 = r'(\w+\()?\(\((\w+)\)\s*=>\s*(.*?)\)\((.+?)\)\)?'

        if '=>' in stmt:
            # Check for immediately invoked arrow function
            match = re.search(pattern4, stmt)
            if match:
                outer_func = match.group(1) or ''
                param = match.group(2)
                body = match.group(3)
                arg = match.group(4)
                closing_paren = ')' if outer_func else ''
                return f"{outer_func}(lambda {param}: {body})({arg}){closing_paren}"
            
            # Check for other arrow function declaration cases
            match = re.match(pattern1, stmt)
            if match:
                var_name = match.group(1)
                params = match.group(2)
                body = match.group(3)
                return f"{var_name} = lambda {params}: {body}"
            match = re.match(pattern2, stmt)
            if match:
                var_name = match.group(1)
                param = match.group(2)
                body = match.group(3)
                return f"{var_name} = lambda {param}: {body}"
            match = re.match(pattern3, stmt)
            if match:
                var_name = match.group(1)
                body = match.group(2)
                return f"{var_name} = lambda: {body}"
        return stmt

    def get_expr_text(self, ctx):
        start_index = ctx.expr().start.start
        stop_index = ctx.expr().stop.stop
        return self.input_stream.getText(start_index, stop_index).strip()

    def getOutput(self):
        return ''.join(self.output)

def transpile_file(input_file, output_file):
    input_stream = FileStream(input_file, encoding='utf-8')
    lexer = Py0Lexer(input_stream)
    stream = CommonTokenStream(lexer)
    parser = Py0Parser(stream)
    tree = parser.program()

    transpiler = Py0ToPythonTranspiler(input_stream)
    walker = ParseTreeWalker()
    walker.walk(transpiler, tree)

    with open(output_file, 'w', encoding='utf-8') as f:
        f.write(transpiler.getOutput())

if __name__ == "__main__":
    transpile_file("input.py0", "output.py")


from setuptools import setup, find_packages

setup(
    name='py0ltv',
    version='0.1.3',
    packages=find_packages(),
    install_requires=[
        'antlr4-python3-runtime',
    ],
    entry_points={
        'console_scripts': [
            'py0=py0.main:main',
        ],
    },
    author='LapTrinhVui',
    author_email='syriackeyboard@gmail.com',
    description='A transpiler for .py0 files to Python',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/ltvtk/py0',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    include_package_data=True,
    package_data={'py0': ['generated/*.py']},
)